@@ -28,7 +28,6 @@
 #' ```
 #'
 #' @inheritParams ClusterFuture-class
-#' @inheritParams multiprocess
 #' @inheritParams Future-class
 #' @inheritParams future
 #'
@@ -40,8 +39,8 @@
 #' @example incl/cluster.R
 #'
 #' @export
-cluster <- function(..., workers = availableWorkers(), envir = parent.frame()) {
-  future <- ClusterFuture(..., workers = workers, envir = envir)
+cluster <- function(..., persistent = FALSE, workers = availableWorkers(), envir = parent.frame()) {
+  future <- ClusterFuture(..., persistent = persistent, workers = workers, envir = envir)
   if (!future$lazy) future <- run(future)
   invisible(future)
 }
