@@ -1,7 +1,7 @@
 #' Create a future
 #'
 ## Rescaled to 120x138: convert -geometry 28.7% future-logo.png logo.png
-#' \if{html}{\figure{logo.png}{options: align='right' alt='logo' width='120'}}
+#' \if{html}{\figure{logo.png}{options: style='float: right;' alt='logo' width='120'}}
 #' Creates a future that evaluates an \R expression or
 #' a future that calls an \R function with a set of arguments.
 #' How, when, and where these futures are evaluated can be configured
@@ -188,6 +188,7 @@
 #' @name future
 future <- function(expr, envir = parent.frame(), substitute = TRUE, lazy = FALSE, seed = FALSE, globals = TRUE, packages = NULL, stdout = TRUE, conditions = "condition", earlySignal = FALSE, label = NULL, gc = FALSE, ...) {
   if (substitute) expr <- substitute(expr)
+  t_start <- Sys.time()
 
   gp <- getGlobalsAndPackages(expr, envir = envir, tweak = tweakExpression, globals = globals)
   expr <- gp$expr
@@ -216,13 +217,18 @@ future <- function(expr, envir = parent.frame(), substitute = TRUE, lazy = FALSE
   ## Comment: Only allowed for persistent 'cluster' futures
   future$.defaultLocal <- !is.element("local", names(list(...)))
 
+  ## Enable journaling?
+  if (getOption("future.journal", FALSE)) {
+    future <- makeFutureJournal(future, event = "create", category = "overhead", start = t_start)
+  }
+
   if (!lazy) {
     future <- run(future)
     future$lazy <- FALSE
     ## Assert that a future was returned
     stop_if_not(inherits(future, "Future"), !future$lazy)
   }
-
+  
   future
 }
 
